<?php

/**
 * Plugin Name: GLS RSS Thumbnails
 * Plugin URI: https://gls-inc.co.jp/archives/435
 * Description: Adds featured images to WordPress RSS feeds. / WordPressのRSSフィードにアイキャッチ画像を追加します。
 * Version: 1.2.1
 * Author: GLS Inc.
 * Author URI: https://gls-inc.co.jp/
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: gls-rss-thumbnails
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/**
 * RSSフィードの description にアイキャッチ画像を追加
 */
function gls_rss_thumbnails_add_to_rss_description($content) {
    global $post;

    if (isset($post) && is_object($post) && has_post_thumbnail($post->ID)) {
        $thumbnail = get_the_post_thumbnail_url($post->ID, 'medium');
        if ($thumbnail) {
            $image_tag = '<p><img src="' . esc_url($thumbnail) . '" alt="" style="max-width:100%;height:auto;" /></p>';
            $content = $image_tag . $content;
        }
    }

    return $content;
}
add_filter('the_excerpt_rss', 'gls_rss_thumbnails_add_to_rss_description');
add_filter('the_content_feed', 'gls_rss_thumbnails_add_to_rss_description');

/**
 * プラグインの設定ページにRSSフィードURLを表示
 */
function gls_rss_thumbnails_add_settings_page() {
    add_options_page(
        'GLS RSS Thumbnails Settings / 設定',
        'GLS RSS Thumbnails',
        'manage_options',
        'gls-rss-thumbnails',
        'gls_rss_thumbnails_settings_page'
    );
}
add_action('admin_menu', 'gls_rss_thumbnails_add_settings_page');

function gls_rss_thumbnails_settings_page() {

    echo '<div class="wrap">';
    echo '<h1>GLS RSS Thumbnails</h1>';  
    echo '<p>The RSS feed URL may vary depending on the WordPress theme you are using.</p><p>Below is the RSS feed URL for your current site, automatically detected based on your site\'s settings.</p>';
    echo '<br>';
    echo '<p>WordPressのテーマによっては、RSSフィードのURLが異なる場合があります。</p><p>下記は、現在ご利用中のサイト設定から自動検出したRSSフィードURLです。</p>';
    echo '<h2>RSS Feed URL / RSSフィードURL</h2>';
    echo '<p><a href="' . esc_url(get_feed_link()) . '" target="_blank">' . esc_html(get_feed_link()) . '</a></p>';
    echo '</div>';
}

/**
 * プラグイン一覧画面に「設定」リンクを追加
 */
function gls_rss_thumbnails_add_settings_link($links) {
    $settings_link = '<a href="' . admin_url('options-general.php?page=gls-rss-thumbnails') . '">' . __('Settings', 'gls-rss-thumbnails') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'gls_rss_thumbnails_add_settings_link');
